@@ -124,7 +124,7 @@ class Skillet(ABC):
         template_file = skillet_path.joinpath(template_path).resolve()
 
         if template_file.exists():
-            with template_file.open() as sf:
+            with template_file.open(encoding='utf-8') as sf:
                 return html.unescape(sf.read())
 
         else:
@@ -341,7 +341,8 @@ class Skillet(ABC):
                             snippet_outputs = snippet.get_default_output(output, status)
                             captured_outputs = snippet.capture_outputs(output, status)
 
-                            if snippet.name in self.snippet_outputs:
+                            # only track snippet output across loops if we actually have loops configured
+                            if snippet.name in self.snippet_outputs and len(loop_vars) > 1:
                                 self.snippet_outputs[snippet.name].append(snippet_outputs)
                             else:
                                 # create a list of track progress here
@@ -563,18 +564,24 @@ class Skillet(ABC):
                     if snippet[k] == v:
                         snippet.pop(k, None)
 
-            # source https://stackoverflow.com/a/45004775
-            yaml.SafeDumper.org_represent_str = yaml.SafeDumper.represent_str
+            if not safe_skillet_dict.get("depends", []):
+                safe_skillet_dict.pop('depends', None)
 
-            def repr_str(dumper, data):
-                if '\n' in data:
-                    return dumper.represent_scalar(u'tag:yaml.org,2002:str', data, style='|')
+            # Custom YAML dumper to inject appropriate white-space
+            class SkilletYamlDumper(yaml.SafeDumper):
+                def write_line_break(self, data=None):
+                    super().write_line_break(data)
+                    if len(self.indents) < 3:
+                        super().write_line_break()
 
-                return dumper.org_represent_str(data)
+            # Add a str presenter for multi-line text
+            def str_presenter(dumper, data):
+                if len(data.splitlines()) > 1:
+                    return dumper.represent_scalar("tag:yaml.org,2002:str", data, style="|")
+                return dumper.represent_scalar("tag:yaml.org,2002:str", data)
+            SkilletYamlDumper.add_representer(str, str_presenter)
 
-            yaml.add_representer(str, repr_str, Dumper=yaml.SafeDumper)
-
-            return yaml.safe_dump(safe_skillet_dict, indent=4)
+            return yaml.dump(safe_skillet_dict, indent=4, Dumper=SkilletYamlDumper)
 
         except (ScannerError, ValueError) as err:
             raise SkilletValidationException(f'Could not dump Skillet as YAML: {err}')
